# malpz

## Overview

The MALPZ (Malware Pickled Zip) format describes a method of neutering malware
while providing a simple, extensible mechanism for capturing metadata.

This project is deprecated and we encourage use of CART format instead.

https://github.com/CybercentreCanada/cart
